==> libreoffice-4.0.5.2.tar.xz: libreoffice-4.0.5.2/svx/source/dialog/stddlg.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <vcl/msgbox.hxx>

#include <svx/stddlg.hxx>

// STATIC DATA -----------------------------------------------------------


// class SvxStandardDialog -----------------------------------------------

short SvxStandardDialog::Execute()
{
    short nRet = ModalDialog::Execute();

    if ( RET_OK == nRet )
        Apply();
    return nRet;
}

// -----------------------------------------------------------------------

SvxStandardDialog::SvxStandardDialog( Window *pParent, const ResId &rResId )
    : SfxModalDialog( pParent, rResId )
{
}

SvxStandardDialog::SvxStandardDialog(Window *pParent, const rtl::OString& rID, const rtl::OUString& rUIXMLDescription )
    : SfxModalDialog(pParent, rID, rUIXMLDescription)
{
}

// -----------------------------------------------------------------------

SvxStandardDialog::~SvxStandardDialog()
{
}



/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-4.2.0.4.tar.xz: libreoffice-4.2.0.4/svx/source/dialog/stddlg.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <vcl/msgbox.hxx>

#include <svx/stddlg.hxx>

// STATIC DATA -----------------------------------------------------------


// class SvxStandardDialog -----------------------------------------------

short SvxStandardDialog::Execute()
{
    short nRet = ModalDialog::Execute();

    if ( RET_OK == nRet )
        Apply();
    return nRet;
}

// -----------------------------------------------------------------------

SvxStandardDialog::SvxStandardDialog( Window *pParent, const ResId &rResId )
    : SfxModalDialog( pParent, rResId )
{
}

SvxStandardDialog::SvxStandardDialog(Window *pParent, const OString& rID, const OUString& rUIXMLDescription )
    : SfxModalDialog(pParent, rID, rUIXMLDescription)
{
}

// -----------------------------------------------------------------------

SvxStandardDialog::~SvxStandardDialog()
{
}



/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
